--------------------------------------------------------------------
--	ADDON: DOOM ROGUELIKE ARSENAL PICKUPS
--------------------------------------------------------------------
--
--	Copyright (C) 2022 xBEEKAYRANDEEx
--	With generous assistance from MsrSgtShooterPerson, dasho, Demios, as well as all of the Obsidian team
--
--  This program is free software; you can redistribute it and/or
--  modify it under the terms of the GNU General Public License
--  as published by the Free Software Foundation; either version 2
--  of the License, or (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
------------------------------------------------------------------------

DOOM_ROGUELIKE_ARSENAL_PICKUPS = { }

--	Table for items that will be added
DOOM_ROGUELIKE_ARSENAL_PICKUPS.CONSUMABLE_ITEMS = 
{
	RLModPackSpawner = 
	{
		id = 16700,
		kind = "other",
		rank = 2,
		level = 5,
		add_prob = 5,
		closet_prob = 10,
		secret_prob = 5,
		storage_prob = 10,
	},
	
	-- Also counts as DRPG supply crates.
	-- Thanks, Demios for pointing this out.
	RLSupplyCrate = 
	{
		id = 16757,
		kind = "other",
		rank = 3,
		add_prob = 0,
		closet_prob = 2,
		secret_prob = 10,
		storage_prob = 10,
	},

	RLGreenArmorSpawner =
	{
		id = 16711,
		kind = "armor",
		rank = 1,
		add_prob = 30,
		closet_prob = 10,
		secret_prob = 30,
		storage_prob = 20,
	},
	
	RLBlueArmorSpawner =
	{
		id = 16712,
		kind = "armor",
		rank = 3,
		add_prob = 6,
		closet_prob = 5,
		secret_prob = 20,
		storage_prob = 15,
	},
}

--	Give the SupplyCrateSpawner a MapID, since it doesn't have one.
--	Thank you to MsrSgtShooterPerson and dasho for the knowledge of how this works.
DOOM_ROGUELIKE_ARSENAL_PICKUPS.DOOMEDNUMS = 
[[
	16757 = RLSupplyCrate
]]

function DOOM_ROGUELIKE_ARSENAL_PICKUPS.setup(self)

		module_param_up(self)
		table.deep_merge(GAME.NICE_ITEMS, DOOM_ROGUELIKE_ARSENAL_PICKUPS.CONSUMABLE_ITEMS)
		--	Make them NICE_ITEMS so they don't get in the way of ammo and health
		--	Thank you, MsrSgtShooterPerson for the assistance and knowledge.
		SCRIPTS.doomednums = ScriptMan_combine_script(SCRIPTS.doomednums, DOOM_ROGUELIKE_ARSENAL_PICKUPS.DOOMEDNUMS)
	
	--  Used in ctl_doom.lua
	local function change_probz(name, info)
    if PARAM[name] and PARAM[name] ~= gui.gettext("Default") then
		local mult = PARAM[name] or 0

		-- Creates a probability based on the item's "prob" values and user-defined mulitplier. (Priority based)
		-- Thanks, dasho for the explanation.
		if info.add_prob then info.add_prob = info.add_prob * mult end
		if info.start_prob then info.start_prob = info.start_prob * mult end
		if info.crazy_prob then info.crazy_prob = info.crazy_prob * mult end
		if info.closet_prob then info.closet_prob = info.closet_prob * mult end
		if info.secret_prob then info.secret_prob = info.secret_prob * mult end
		if info.storage_prob then info.storage_prob = info.storage_prob * mult end
		end
	end

	for name, info in pairs(GAME.NICE_ITEMS) do
		float_name = "float_" .. name
		change_probz(float_name, info)
	end
end

--	Make the addon exist in Obsidian's UI
OB_MODULES["doom_roguelike_arsenal_pickups"] =
{
	label = _("Doom Roguelike Arsenal Pickups"),
	side = "right",
	priority = -110,
	tooltip = "Adds weapons, armor, and modpack spawners from Doom Roguelike Arsenal.",
	game = "doomish",
	port = "zdoom",		--DRLA doesn't work in anything but GZDoom or LZDoom, so don't change this.
	hooks = 
	{
		setup = DOOM_ROGUELIKE_ARSENAL_PICKUPS.setup,
--	Hooks are functions you can write into based on what state in the level generation is the generator in = module initialization for .setup
--	Thank you, MsrSgtShooterPerson for the assistance and knowledge.
	},
	options =
	{
		{ 	
			name = "float_RLModPackSpawner",
			label = _("Modpack"),
			valuator = "slider",
			min = 0,
			max = 10,
			increment = 0.25,
			default = _("Default"),
			nan = _("Default"),
			tooltip = _("Sets the amount of DoomRLA modpack spawns."),
			presets = _("0:0 (Purist), 0.25:0.25 (Lucky Day), 0.75:0.75 (Scavenger), 1:1 (Default), 2:2 (Plenty), 5:5 (Cheater), 10:10 (Yholl Weeps)"),
			--  randomize_group allows the module to be randomized in the "Surprise Me" category.
			randomize_group = "pickups"
		},

		{
			name = "float_RLSupplyCrateSpawner",
			label = _("Supply Crate"),
			valuator = "slider",
			min = 0,
			max = 10,
			increment = 0.25,
			default = _("Default"),
			nan = _("Default"),
			tooltip = _("Sets the amount of DoomRLA supply crate spawns."),
			presets = _("0:0 (Purist), 0.25:0.25 (Lucky Day), 0.75:0.75 (Scavenger), 1:1 (Default), 2:2 (Plenty), 5:5 (Cheater), 10:10 (Yholl Weeps)"),
			randomize_group = "pickups"
		},

		{
			name = "float_RLGreenArmorSpawner",
			label = _("Basic Armor"),
			valuator = "slider",
			min = 0,
			max = 10,
			increment = 0.25,
			default = _("Default"),
			nan = _("Default"),
			tooltip = _("Sets the amount of DoomRLA weak (green) armor spawns."),
			presets = _("0:0 (Purist), 0.25:0.25 (Lucky Day), 0.75:0.75 (Scavenger), 1:1 (Default), 2:2 (Plenty), 5:5 (Cheater), 10:10 (Yholl Weeps)"),
			randomize_group = "pickups"
		},

		{
			name = "float_RLBlueArmorSpawner",
			label = _("Rare Armor"),
			valuator = "slider",
			min = 0,
			max = 10,
			increment = 0.25,
			default = _("Default"),
			nan = _("Default"),
			tooltip = _("Sets the amount of DoomRLA strong (blue) armor spawns."),
			presets = _("0:0 (Purist), 0.25:0.25 (Lucky Day), 0.75:0.75 (Scavenger), 1:1 (Default), 2:2 (Plenty), 5:5 (Cheater), 10:10 (Yholl Weeps)"),
			randomize_group = "pickups"
		}
	}
}